<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: DateRangeField.php 4624 2006-04-06 10:37:29Z matteo@beccati.com $
*/

require_once MAX_PATH . '/lib/max/Dal/Reporting.php';
require_once MAX_PATH . '/lib/max/DateRange.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/ZoneScope.php';
require_once MAX_PATH . '/lib/max/Admin/Reporting/Field.php';

class DateRangeField extends Field
{
    /* @var string */
    var $_fieldName;
    /* @var DaySpan */
    var $_dateRange;
    /* @var array */
    var $_fields;
    /* @var string */
    var $_fieldNameDefault;

    function __construct($aFields = array('lastmonth' => 'Last month','lastweek' => 'Last week','last7days' => 'Last 7 days','thismonth' => 'This month','thisweek' => 'This week','specific' => 'Custom dates'), $fieldNameDefault = 'lastmonth')
    {
        $this->_fields = $aFields;
        $this->_fieldNameDefault = $fieldNameDefault;
        $this->_dateRange = new DaySpan($fieldNameDefault);
    }

    function DateRangeField($aFields = array('lastmonth' => 'Last month','lastweek' => 'Last week','last7days' => 'Last 7 days','thismonth' => 'This month','thisweek' => 'This week','specific' => 'Custom dates'), $fieldNameDefault = 'lastmonth')
    {
        $this->__construct($aFields, $fieldNameDefault);
    }

    function isLastMonth()
    {
        if ($this->_week)
        {
            return false;
        }
        return true;
    }

    function isLastWeek()
    {
        return $this->_week;
    }

    function useLastWeek()
    {
        $this->_range->useLastWeek();
        $this->_week = true;
    }

    function getStartDate()
    {
        return $this->_range->getStartDate();
    }

    function getEndDate()
    {
        return $this->_range->getEndDate();
    }

    function _displaySelector($key)
    {
        $overall_name = $key;
        $preset_id = $overall_name . '_preset';

        echo "
        <select name='$preset_id' id='$preset_id' onchange='{$key}FormChange(this, 0, 1)' tabindex='" . $this->tabkeeper->tabindex++ . "'>";

        foreach ($aFields as $field => $name) {
            $selected = $field == $default ? " selected='selected'" : '';
            echo "
            <option value='$field'$selected>$name</option>
            ";
        }
        echo "
        </select>";
    }

    function display($fields, $key)
    {
        $this->_displayFieldHeader($fields[$key]['title']);
        $overall_name = $key;
        $preset_id = $overall_name . '_preset';
        $start_id = $overall_name . '_start';
        $end_id = $overall_name . '_end';
        $start_button_id = $start_id . '_button';
        $end_button_id = $end_id . '_button';

        if (isset($fields[$key]['default'])) {
            $range = $this->getPassableValueFromQueryArray($fields[$key]['default'], $key);
        } else {
            $range = $this->getPassableValueFromQueryArray(array($key.'_preset' => 'thismonth'), $key);
        }

        $start_date = $range->getStartDate();
        $end_date = $range->getHumanEndDate();

        if (is_object($end_date) && $end_date->isFuture()) {
            $end_date = new Date();
        }

        $this->_displaySelector($key, $fields);

        echo "
        <label for='$start_id'>{$GLOBALS['strFrom']}</label>
        <input class='date' name='$start_id' id='$start_id' type='text' value='" . is_null($start_date) ? '' : $start_date->format('%Y-%m-%d') . "'/>
        <button id='$start_button_id'>...</button>

        <label for='$end_id'>{$GLOBALS['strTo']}</label>
        <input class='date' name='$end_id' id='$end_id' type='text' value='" . is_null($start_date) ? '' : $end_date->format('%Y-%m-%d') . "' />
        <button id='$end_button_id'>...</button>";

        $this->_displayFieldFooter();
    }

    function displayExtrasAfterForm($fields, $key)
    {
        $overall_name = $key;
        $preset_id = $overall_name . '_preset';
        $start_id = $overall_name . '_start';
        $end_id = $overall_name . '_end';
        $start_button_id = $start_id . '_button';
        $end_button_id = $end_id . '_button';
        ?>
    <script type='text/javascript'>

        Calendar.setup({
            inputField : '<?php print $start_id; ?>',
            ifFormat   : '%Y-%m-%d',
            button     : '<?php print $start_button_id; ?>',
            align      : 'Bl',
            weekNumbers: false,
            firstDay   : <?php print $GLOBALS['pref']['begin_of_week'] ? 1 : 0; ?>,
            electric   : false
        })
        Calendar.setup({
            inputField : '<?php print $end_id; ?>',
            ifFormat   : '%Y-%m-%d',
            button     : '<?php print $end_button_id; ?>',
            align      : 'Bl',
            weekNumbers: false,
            firstDay   : <?php print $GLOBALS['pref']['begin_of_week'] ? 1 : 0; ?>,
            electric   : false
        })

        function <?php print $key; ?>FormChange(o, bReload, bReset) {
            var specific = o.options[o.selectedIndex].value == 'specific';

            document.getElementById('<?php print $start_id; ?>').disabled = !specific;
            document.getElementById('<?php print $start_button_id; ?>').disabled = !specific;
            document.getElementById('<?php print $end_id; ?>').disabled = !specific;
            document.getElementById('<?php print $end_button_id; ?>').disabled = !specific;

            if (bReset && !specific) {
                document.getElementById('<?php print $start_id; ?>').value =
                    document.getElementById('<?php print $end_id; ?>').value = '';
            }

            if (bReload && !specific)
                o.form.submit();
        }
        function <?php print $key; ?>FormSubmit() {
            document.getElementById('<?php print $preset_id; ?>').form.submit();
            return false;
        }
        <?php print $key; ?>FormChange(document.getElementById('<?php print $preset_id; ?>'), 0, 0);
    </script>

        <?php
    }

    function getPassableValueFromQueryArray($values, $base_key)
    {
        $range = new DateRange($this->_now);
        $range->setStartOfWeek($GLOBALS['pref']['begin_of_week']);
        $range->useValuesFromQueryArray($values, $base_key);
        return $range;
    }

    function getRepresentativeValue()
    {
        return $this->_range;
    }
}

?>
