<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: StatsCrossEntityController.php 4638 2006-04-07 08:54:05Z matteo@beccati.com $
*/

require_once MAX_PATH . '/lib/max/Admin/Statistics/StatsByEntityController.php';



/**
 * Controller class for displaying cross-entities type statistics screens
 *
 * Always use the factory method to instantiate fields -- it will create
 * the right subclass for you.
 *
 * @package    Max
 * @subpackage Admin_Statistics
 * @author     Matteo Beccati <matteo@beccati.com>
 *
 * @see StatsControllerFactory
 */
class StatsCrossEntityController extends StatsByEntityController
{
    /**
     * PHP5-style constructor
     */
    function __constructor()
    {
        // Override links
        $this->entityLinks = array();
        
        parent::__constructor();
    }
    
    /**
     * PHP4-style constructor
     */
    function StatsCrossEntityController()
    {
        $this->__constructor();
    }
    
    /**
     * Merge aggregate stats with entity properties (name, children, etc)
     *
     * The overridden method also takes care to remove inactive entities
     * and to enforce the anonymous properties when logged in as advertiser
     * or publisher
     *
     * @param array Query parameters
     * @param string Key name
     * @return array Full entity stats with entity data
     */
    function mergeData($aParams, $key)
    {
        $aEntities = parent::mergeData($aParams, $key);
        
        $aAnonAdvertisers = array();
        $aAnonPlacements  = array();
        if (phpAds_isUser(phpAds_Client) || phpAds_isUser(phpAds_Affiliate)) {
            $aPlacements = Admin_DA::fromCache('getPlacements', array('placement_anonymous' => true));
            foreach ($aPlacements as $placementId => $placement) {
                $aAnonAdvertisers[$placement['advertiser_id']] = true;
                $aAnonPlacements[$placementId] = true;
            }
        }
        
        foreach (array_keys($aEntities) as $entityId) {
            if (!isset($this->data[$key][$entityId])) {
                unset($aEntities[$entityId]);
            } elseif ($key == 'advertiser_id' && isset($aAnonAdvertisers[$entityId])) {
                    $aEntities[$entityId]['hidden'] = true;
            } elseif ($key == 'placement_id' && isset($aAnonPlacements[$entityId])) {
                    $aEntities[$entityId]['hidden'] = true;
            } elseif ($key == 'ad_id' && isset($aAnonPlacements[$aEntities[$entityId]['placement_id']])) {
                    $aEntities[$entityId]['hidden'] = true;
            } elseif (phpAds_isUser(phpAds_Client)) {
                if (isset($aParams['placement_id'])) {
                    $aEntities[$entityId]['hidden'] = isset($aAnonPlacements[$aParams['placement_id']]);
                } else {
                    $aEntities[$entityId]['hidden'] = isset($aAnonAdvertisers[phpAds_getUserId()]);
                }
            }
        }
        
        return $aEntities;
    }
    
    /**
     * Mask entities which have the hidden flag set
     *
     * @param array Entities array
     * @param string Name which should be used for hidden entitiies
     */
    function maskHiddenEntities(&$aEntities, $name)
    {
        foreach (array_keys($aEntities) as $entityId) {
            if (isset($aEntities[$entityId]['hidden']) && $aEntities[$entityId]['hidden']) {
                $aEntities[$entityId]['name'] = $name;
                $aEntities[$entityId]['id']   = '-';
                $aEntities[$entityId]['num_children'] = 0;
                unset($aEntities[$entityId]['subentities']);
            }
        }
        
        if ($this->listOrderField == 'name' || $this->listOrderField == 'id') {
            MAX_sortArray(
                $aEntities,
                $this->listOrderField,
                $this->listOrderDirection == 'up'
            );
        }
    }
    
    function getAdvertisers($aParams, $level, $expand = '')
    {
        $aEntities = parent::getAdvertisers($aParams, $level, $expand);
        
        $this->maskHiddenEntities($aEntities, $GLOBALS['strHiddenAdvertiser']);
        
        return $aEntities;
    }
    
    function getCampaigns($aParams, $level, $expand = '')
    {
        $aEntities = parent::getCampaigns($aParams, $level, $expand);
        
        $this->maskHiddenEntities($aEntities, $GLOBALS['strHiddenCampaign']);
        
        return $aEntities;
    }
    
    function getBanners($aParams, $level, $expand = '')
    {
        $aEntities = parent::getBanners($aParams, $level, $expand);
        
        $this->maskHiddenEntities($aEntities, $GLOBALS['strHiddenBanner']);
        
        return $aEntities;
    }
    
    function getPublishers($aParams, $level, $expand = '')
    {
        $aEntities = parent::getPublishers($aParams, $level, $expand);
        
        $this->maskHiddenEntities($aEntities, $GLOBALS['strHiddenPublisher']);
        
        return $aEntities;
    }
    
    function getZones($aParams, $level, $expand = '')
    {
        $aEntities = parent::getZones($aParams, $level, $expand);
        
        $this->maskHiddenEntities($aEntities, $GLOBALS['strHiddenZone']);
        
        return $aEntities;
    }
}

?>
