<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: DaySpan.php 4346 2006-03-06 16:43:19Z andrew@m3.net $
*/

/**
 * A view field for the DaySpan object.
 *
 * @package    Max
 * @author     Scott Switzer <scott@switzer.org>
 */
require_once MAX_PATH . '/lib/max/DaySpan.php';
require_once MAX_PATH . '/lib/max/Admin/UI/Field.php';

class Admin_UI_DateRangeField extends Admin_UI_Field
{
    /* @var string */
    var $_fieldSelectionValue;
    /* @var array */
    var $_fieldSelectionNames;
    /* @var boolean */
    var $_autoSubmit;

    /**
     * PHP5-style constructor
     *
     * @param array $aFieldSelectionNames A list of the predefined 'friendly' selections.
     * @param string $fieldSelectionDefault The default selection.
     */
    function __construct($name = 'DateRangeField', 
                         $fieldSelectionDefault = 'last_month',
                         $aFieldSelectionNames = null
                        )
    {
        if (is_null($aFieldSelectionNames)) {
            $aFieldSelectionNames= array(
                'today'       => $GLOBALS['strCollectedToday'],
                'yesterday'   => $GLOBALS['strCollectedYesterday'],
                'this_week'   => $GLOBALS['strCollectedThisWeek'],
                'last_week'   => $GLOBALS['strCollectedLastWeek'],
                'last_7_days' => $GLOBALS['strCollectedLast7Days'],
                'this_month'  => $GLOBALS['strCollectedThisMonth'],
                'last_month'  => $GLOBALS['strCollectedLastMonth'],
                'specific'    => $GLOBALS['strCollectedSpecificDates']
              );
        }
        $this->_name = $name;
        $this->_fieldSelectionNames = $aFieldSelectionNames;
        $this->_value = new DaySpan($fieldSelectionDefault);
        $this->_autoSubmit = false;
    }


    /**
     * PHP4-style constructor
     *
     * @param array $aFieldSelectionNames A list of the predefined 'friendly' selections.
     * @param string $fieldSelectionDefault The default selection.
     */
    function Admin_UI_DateRangeField($name = 'DateRangeField', 
                                     $fieldSelectionDefault = 'last_month',
                                     $aFieldSelectionNames = null
                                    )
    {
        $this->__construct($name, $fieldSelectionDefault, $aFieldSelectionNames);
    }
    /**
     * A method to set the value of the field using a preset 'friendly' selection.
     *
     * @param string $presetValue The preset value.
     */
    function setValue($presetValue)
    {
        $this->_fieldSelectionValue = $presetValue;
        $this->_value = new DaySpan($presetValue);
    }
    /**
     * A method to set the value of the field using the input querystring fields passed in from the HTML.
     *
     * @param array $aQuerystring The querystring of this field.
     */
    function setValueFromArray($aFieldValues)
    {
        $fieldSelectionName = $aFieldValues[$this->_name . '_preset'];
        if (!empty($fieldSelectionName)) {
            if ($fieldSelectionName == 'specific') {
                $oDaySpan = new DaySpan();
                $sStartDate = $aFieldValues[$this->_name . '_start'];
                $oStartDate = new Date();
                $oStartDate->setDate($sStartDate);
                $sEndDate = $aFieldValues[$this->_name . '_end'];
                $oEndDate = new Date();
                $oEndDate->setDate($sEndDate);
                $oDaySpan->setSpanDays($oStartDate, $oEndDate);
            } else {
                $oDaySpan = new DaySpan($fieldSelectionName);
            }
            $this->_value = $oDaySpan;
            $this->_fieldSelectionValue = $fieldSelectionName;
        }
    }
    /**
     * A method that retrieves the start date of this field's DaySpan.
     *
     * @return Date the start date of the this field.
     */
    function getStartDate()
    {
        $oDaySpan = $this->_value;
        $value = is_null($oDaySpan) ? null : $oDaySpan->getStartDate();
        return $value;
    }
    /**
     * A method that retrieves the end date of this field's DaySpan.
     *
     * @return Date the end date of the this field.
     */
    function getEndDate()
    {
        $oDaySpan = $this->_value;
        $value = is_null($oDaySpan) ? null : $oDaySpan->getEndDate();
        return $value;
    }
    /**
     * A method that returns an array representing the start and end dates of the span.
     *
     * @return array the begin and end dates of the span
     */
    function getDateRangeArray()
    {
        $aDateRange = array();
        $oDaySpan = $this->_value;
        if (!empty($oDaySpan)) {
            $aDateRange['day_begin'] = $oDaySpan->getStartDateString();
            $aDateRange['day_end'] = $oDaySpan->getEndDateString();
        }
        return $aDateRange;
    }
    /**
     * A method that echos the HTML for this field.
     */
    function display()
    {
        $name = $this->_name;
        $startDate = $this->getStartDate();
        $startDateStr = is_null($startDate) ? '' : $startDate->format('%Y-%m-%d');
        $endDate = $this->getEndDate();
        $endDateStr = is_null($endDate) ? '' : $endDate->format('%Y-%m-%d');
        $fieldSelectionValue = $this->_fieldSelectionValue;
        $aFieldSelectionNames = $this->_fieldSelectionNames;


        echo "
        <select name='{$name}_preset' id='{$name}_preset' onchange='{$name}FormChange(this, " . ($this->_autoSubmit ? 1 : 0) . ")' tabindex='" . $this->_tabIndex++ . "'>";

        foreach ($aFieldSelectionNames as $v => $n) {
            $selected = $v == $fieldSelectionValue ? " selected='selected'" : '';
            echo "
            <option value='{$v}'{$selected}>{$n}</option>";
        }
        echo "
        </select>
        <label for='{$name}_start'> From</label>
        <input class='date' name='{$name}_start' id='{$name}_start' type='text' value='$startDateStr'/>
        <button id='{$name}_start_button'>...</button>
        <label for='{$name}_end'> To</label>
        <input class='date' name='{$name}_end' id='{$name}_end' type='text' value='$endDateStr'/>
        <button id='{$name}_end_button'>...</button>
        <script type='text/javascript'>
        <!--
        Calendar.setup({
            inputField : '{$name}_start',
            ifFormat   : '%Y-%m-%d',
            button     : '{$name}_start_button',
            align      : 'Bl',
            weekNumbers: false,
            firstDay   : " . ($GLOBALS['pref']['begin_of_week'] ? 1 : 0) . ",
            electric   : false
        })
        Calendar.setup({
            inputField : '{$name}_end',
            ifFormat   : '%Y-%m-%d',
            button     : '{$name}_end_button',
            align      : 'Bl',
            weekNumbers: false,
            firstDay   : " . ($GLOBALS['pref']['begin_of_week'] ? 1 : 0) . ",
            electric   : false
        })
        function {$name}Reset()
        {
            document.getElementById('{$name}_start').value = '$startDateStr';
            document.getElementById('{$name}_start').value = '$endDateStr';
            document.getElementById('{$name}_preset').value = '$fieldSelectionValue';
        }
        function {$name}FormSubmit() {
            document.getElementById('{$name}_preset').form.submit();
            return false;
        }
        function {$name}FormChange(o, bAutoSubmit)
        {
            var {$name}SelectName = o.options[o.selectedIndex].value;
            var specific = {$name}SelectName == 'specific';";

        $oTmpDaySpan = new DaySpan();
        foreach ($aFieldSelectionNames as $v => $n) {
            if ($v != 'specific') {
                $oTmpDaySpan->setSpanPresetValue($v);
                $oTmpStartDate = $oTmpDaySpan->getStartDate();
                $sTmpStartDate = $oTmpStartDate->format('%Y-%m-%d');
                $oTmpEndDate = $oTmpDaySpan->getEndDate();
                $sTmpEndDate = $oTmpEndDate->format('%Y-%m-%d');
                echo "
            if ({$name}SelectName == '$v') {
                document.getElementById('{$name}_start').value = '$sTmpStartDate';
                document.getElementById('{$name}_end').value = '$sTmpEndDate';
            }
                ";
            }
        }
        echo "

            document.getElementById('{$name}_start').disabled = !specific;
            document.getElementById('{$name}_start_button').disabled = !specific;
            document.getElementById('{$name}_end').disabled = !specific;
            document.getElementById('{$name}_end_button').disabled = !specific;
            
            if (!specific && bAutoSubmit) {
                o.form.submit();
            }
        }
        {$name}FormChange(document.getElementById('{$name}_preset', " . ($this->_autoSubmit ? 1 : 0) . "));
        //-->
        </script>";
    }
}

?>
