<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: AllocateZoneImpressions.php 4346 2006-03-06 16:43:19Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/Max.php';
require_once MAX_PATH . '/lib/max/Dal/Maintenance.php';
require_once MAX_PATH . '/lib/max/Maintenance/Statistics/Common/Task.php';

/**
 * A abstract class, definine a common method for deleting old data for
 * maintenance statistics module classes.
 *
 * @abstract
 * @package    MaxMaintenance
 * @subpackage Statistics
 * @author     Andrew Hill <andrew@m3.net>
 */
class MAX_Maintenance_Statistics_Common_Task_DeleteOldData extends MAX_Maintenance_Statistics_Common_Task
{

    /**
     * The constructor method.
     *
     * @return MAX_Maintenance_Statistics_Common_Task_DeleteOldData
     */
    function MAX_Maintenance_Statistics_Common_Task_DeleteOldData()
    {
        parent::MAX_Maintenance_Statistics_Common_Task();
    }

    /**
     * The implementation of the MAX_Core_Task::run() method that performs
     * the task of this class. Intended to be inherited by childred of this
     * class.
     */
    function run()
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        if ($conf['maintenance']['compactStats']) {
            $time = time();
            if (($this->oController->updateFinal) && ($this->oController->updateUsingOI)) {
                // Have updated the final table stats, and the operation interval is less than
                // or equal to an hour, so it's safe to delete the statistics that have been
                // summarised now
                $oSummarisedToDate = new Date();
                $oSummarisedToDate->copy($this->oController->updateFinalToDate);
            } elseif (($this->oController->updateIntermediate) && (!$this->oController->updateUsingOI)) {
                // Have updated the intermediate table stats, and the operation interval is
                // more than an hour, so it's safe to delete the statistics that have been
                // summarised now
                $oSummarisedToDate = new Date();
                $oSummarisedToDate->copy($this->oController->updateIntermediateToDate);
            }
            if (!is_null($oSummarisedToDate)) {
                $oServiceLocator = &ServiceLocator::instance();
                $oDal = &$oServiceLocator->get('MAX_Dal_Statistics_' . $this->oController->module);
                $rows = $oDal->deleteOldData($oSummarisedToDate);
                $time = time() - $time;
                if ($conf['table']['split']) {
                    $this->report .= "\nDropped $rows tables of old, summarised data in $time seconds.\n";
                    $message = "Dropped $rows tables of old, summarised data in $time seconds";
                } else {
                    $this->report .= "\nDeleted $rows rows of old, summarised data in $time seconds.\n";
                    $message = "Deleted $rows rows of old, summarised data in $time seconds";
                }
                MAX::debug($message, PEAR_LOG_DEBUG);
            }
        }
    }

}

?>
