<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: DateRange.sdh.test.php 4559 2006-04-03 15:00:09Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/max/DateRange.php';
require_once 'Date.php';

class DateRangeTest extends UnitTestCase
{
    function testTodayFactory()
    {
        $now = new Date('1987-04-12 15:10:11');
        $today_start = new Date('1987-04-12 00:00:00');
        $today_end = new Date('1987-04-13 00:00:00');

        $range = DateRange::newToday($now);

        $this->assertEqual($range->getStartDate(), $today_start);
        $this->assertEqual($range->getEndDate(), $today_end, '"Today" ends at midnight tonight, which is the instant tomorrow begins. %s');
    }

    function testUseYesterday()
    {
        $now = new Date('2000-01-01 00:20:40');
        $yesterday_start = new Date('1999-12-31 00:00:00');
        $yesterday_end = new Date('2000-01-01 00:00:00');

        $range = new DateRange($now);
        $range->useYesterday();

        $this->assertEqual($range->getStartDate(), $yesterday_start);
        $this->assertEqual($range->getEndDate(), $yesterday_end);
    }

    function testUseThisWeek_Sunday()
    {
        $now = new Date('1999-12-24 00:20:40');
        $week_start = new Date('1999-12-19 00:00:00');
        $week_end = new Date('1999-12-26 00:00:00');

        $range = new DateRange($now);
        $range->setStartOfWeek(0); // Sunday
        $range->useThisWeek();

        $this->assertEqual($range->getStartDate(), $week_start);
        $this->assertEqual($range->getEndDate(), $week_end, 'When "start of week" is 0, "this week" ends on midnight spanning Saturday/Sunday. %s');
    }

    function testUseThisWeek_Monday()
    {
        $now = new Date('1999-12-24 00:20:40');
        $week_start = new Date('1999-12-20 00:00:00');
        $week_end = new Date('1999-12-27 00:00:00');

        $range = new DateRange($now);
        $range->setStartOfWeek(1); // Monday
        $range->useThisWeek();

        $this->assertEqual($range->getStartDate(), $week_start);
        $this->assertEqual($range->getEndDate(), $week_end, 'When "start of week" is 1, "this week" ends on midnight spanning Sunday/Monday. %s');
    }

    function testUseLastWeek_Sunday()
    {
        $now = new Date('2000-01-01 00:20:40');
        $week_start = new Date('1999-12-19 00:00:00');
        $week_end = new Date('1999-12-26 00:00:00');

        $range = new DateRange($now);
        $range->setStartOfWeek(0); // Sunday
        $range->useLastWeek();

        $this->assertEqual($range->getStartDate(), $week_start);
        $this->assertEqual($range->getEndDate(), $week_end, 'When "start of week" is 0, "last week" ends on midnight spanning Saturday/Sunday. %s');
    }

    function testUseLastWeek_Monday()
    {
        $now = new Date('2000-01-01 00:20:40');
        $week_start = new Date('1999-12-20 00:00:00');
        $week_end = new Date('1999-12-27 00:00:00');

        $range = new DateRange($now);
        $range->setStartOfWeek(1); // Monday
        $range->useLastWeek();

        $this->assertEqual($range->getStartDate(), $week_start);
        $this->assertEqual($range->getEndDate(), $week_end, 'When "start of week" is 1, "last week" ends on midnight spanning Sunday/Monday. %s');
    }

    function testUseLastWeek_Default()
    {
        $now = new Date('2000-01-01 00:20:40');
        $week_start = new Date('1999-12-19 00:00:00');
        $week_end = new Date('1999-12-26 00:00:00');

        $range = new DateRange($now);
        $range->useLastWeek();

        $this->assertEqual($range->getStartDate(), $week_start);
        $this->assertEqual($range->getEndDate(), $week_end, 'By default, "last week" ends on midnight spanning Saturday/Sunday. %s');
    }

    function testUseLast7Days()
    {
        $now = new Date('2000-01-19 15:20:40');
        $week_start = new Date('2000-01-12 00:00:00');
        $week_end = new Date('2000-01-19 00:00:00');

        $range = new DateRange($now);
        $range->useLast7Days();

        $this->assertEqual($range->getStartDate(), $week_start);
        $this->assertEqual($range->getEndDate(), $week_end);
    }

    function testUseLast17Days()
    {
        $now = new Date('2000-01-19 15:20:40');
        $week_start = new Date('2000-01-02 00:00:00');
        $week_end = new Date('2000-01-19 00:00:00');

        $range = new DateRange($now);
        $range->useLastDays(17);

        $this->assertEqual($range->getStartDate(), $week_start);
        $this->assertEqual($range->getEndDate(), $week_end);
    }

    function testUseLastMonth()
    {
        $now = new Date('2000-01-19 15:20:40');
        $month_start = new Date('1999-12-01 00:00:00');
        $month_end = new Date('2000-01-01 00:00:00');

        $range = new DateRange($now);
        $range->useLastMonth();

        $this->assertEqual($range->getStartDate(), $month_start);
        $this->assertEqual($range->getEndDate(), $month_end);
    }

    function testUseThisMonth()
    {
        $now = new Date('2000-01-19 15:20:40');
        $month_start = new Date('2000-01-01 00:00:00');
        $month_end = new Date('2000-02-01 00:00:00');

        $range = new DateRange($now);
        $range->useThisMonth();

        $this->assertEqual($range->getStartDate(), $month_start);
        $this->assertEqual($range->getEndDate(), $month_end);
    }

    function testUseNextMonth()
    {
        $now = new Date('2000-01-19 15:20:40');
        $month_start = new Date('2000-02-01 00:00:00');
        $month_end = new Date('2000-03-01 00:00:00');

        $range = new DateRange($now);
        $range->useNextMonth();

        $this->assertEqual($range->getStartDate(), $month_start);
        $this->assertEqual($range->getEndDate(), $month_end);
    }

    function testUseMonthRemainder()
    {
        $now = new Date('2000-01-19 15:20:40');
        $month_start = new Date('2000-01-19 00:00:00');
        $month_end = new Date('2000-02-01 00:00:00');

        $range = new DateRange($now);
        $range->useMonthRemainder();

        $this->assertEqual($range->getStartDate(), $month_start, 'The rest of the month starts this morning. %s');
        $this->assertEqual($range->getEndDate(), $month_end, 'The rest of the month ends after the last second of this month. %s');
    }

    function testGetStartSql()
    {
        $now = new Date('2000-01-19 15:20:40');
        $range = new DateRange($now);
        $range->useToday();
        $sql = $range->getStartSql();
        $this->assertEqual($sql, "'2000-01-19 00:00:00'");
    }

    function testGetEndSql_Seconds()
    {
        $now = new Date('2000-01-19 15:20:40');
        $range = new DateRange($now);
        $range->useToday();
        $sql = $range->getEndSqlForComparingTimestamps();
        $this->assertEqual($sql, "'2000-01-20 00:00:00'");
    }

    function testGetEndSql_Days()
    {
        $now = new Date('2000-01-19 15:20:40');
        $range = new DateRange($now);
        $range->useToday();
        $sql = $range->getEndSqlForComparingDays();
        $this->assertEqual($sql, "'2000-01-19'");
    }

    function testGetStartDateForDisplay()
    {
        $now = new Date('2000-01-19 15:20:40');
        $range = new DateRange($now);
        $range->useToday();
        $display = $range->getStartDateForDisplay();
        $this->assertEqual($display, '19/01/2000');
    }

    function testGetEndDateForDisplay()
    {
        $now = new Date('2000-01-19 15:20:40');
        $range = new DateRange($now);
        $range->useToday();
        $display = $range->getEndDateForDisplay();
        $this->assertEqual($display, '19/01/2000');
    }

    function testGetStartDateForFilename()
    {
        $now = new Date('2000-01-19 15:20:40');
        $range = new DateRange($now);
        $range->useToday();
        $display = $range->getStartDateForFilename();
        $this->assertEqual($display, '2000-Jan-19');
    }

    function testGetEndDateForFilename()
    {
        $now = new Date('2000-01-19 15:20:40');
        $range = new DateRange($now);
        $range->useToday();
        $display = $range->getEndDateForFilename();
        $this->assertEqual($display, '2000-Jan-19');
    }

    function testHumansSeeWhatTheyPutIn()
    {
        $range = new DateRange();
        $range->setDateRangeByNaturalHumanStrings('2001-01-19', '2001-01-20');
        $display = $range->getEndDateForDisplay();
        $this->assertEqual($display, '20/01/2001', 'The last day of the range the user asks for should be the same as the one displayed, even if internal representation is different. %s');
    }

    function testSettingInclusiveDates()
    {
        $range = new DateRange();
        $monday = new Date('2001-01-01');
        $friday = new Date('2001-01-05');
        $range->setDateRangeByInclusiveDates($monday, $friday);
        $this->assertEqual($range->countDays(), 5, 'Monday to Friday inclusive is five days. %s');
    }

    function testDetectionOfRangeEndingBeforeItBegins_Negative()
    {
        $range = new DateRange();
        $monday = new Date('2001-01-01');
        $friday = new Date('2001-01-05');
        $range->setDateRangeByInclusiveDates($monday, $friday);
        $this->assertFalse($range->endsBeforeStarts(), 'Friday (the end of the range) is before Monday (the start of the range) so the range is fine');
    }

    function testDetectionOfRangeEndingBeforeItBegins_Positive()
    {
        $range = new DateRange();
        $monday = new Date('2001-01-01');
        $friday = new Date('2001-01-05');
        $range->setDateRangeByInclusiveDates($friday, $monday);
        $this->assertTrue($range->endsBeforeStarts(), 'Monday (the end of the range) is before Friday (the start of the range) so the range is skewed');
    }

    function testCountDaysInRange_Simple()
    {
        $now = new Date('1999-06-16');
        $range = new DateRange($now);
        $range->useThisMonth();
        $days = $range->countDays();
        $this->assertEqual($days, 30, 'There were 30 days in June 1999. %s');
    }

    function testCountDaysInRange_CrossYear()
    {
        $now = new Date('2001-01-03');
        $range = new DateRange($now);
        $range->useLast7Days();
        $days = $range->countDays();
        $this->assertEqual($days, 7, 'Asking for seven days should give seven days. %s');
    }

    function testCountMondaysInJune1999()
    {
        $now = new Date('1999-06-16');
        $range = new DateRange($now);
        $range->useThisMonth();
        $mondays = $range->countDayOfWeekOccurances(1);
        $this->assertEqual($mondays, 4, 'There were four Mondays in June 1999. %s');
    }

    function testCountMondaysInJune1998()
    {
        $now = new Date('1998-06-16');
        $range = new DateRange($now);
        $range->useThisMonth();
        $mondays = $range->countDayOfWeekOccurances(1);
        $this->assertEqual($mondays, 5, 'There were five Mondays in June 1998. %s');
    }

    function testCountSundays_ZeroBased()
    {
        $now = new Date('1998-06-16');
        $range = new DateRange($now);
        $range->useThisMonth();
        $sundays = $range->countDayOfWeekOccurances(0, 0);
        $this->assertEqual($sundays, 4, 'There were four Sundays in June 1998. %s');
    }

    function testCountSundays_SevenBased()
    {
        $now = new Date('1998-06-16');
        $range = new DateRange($now);
        $range->useThisMonth();
        $sundays = $range->countDayOfWeekOccurances(7, 7);
        $this->assertEqual($sundays, 4, 'There were four Sundays in June 1998. %s');
    }

    function testCountSundays_LastDayOfRangeIsCounted()
    {
        $now = new Date('2004-02-02');
        $range = new DateRange($now);
        $range->useThisMonth();
        $sundays = $range->countDayOfWeekOccurances(0);
        $this->assertEqual($sundays, 5, 'February 2004 began on a Sunday and ended on a Sunday. %s');
    }

    function testCountSundays_OnlyDaysInRangeAreCounted()
    {
        $now = new Date('2005-02-02');
        $range = new DateRange($now);
        $range->useThisMonth();
        $sundays = $range->countDayOfWeekOccurances(2);
        $this->assertEqual($sundays, 4, 'February 2005 began on a Tuesday and ended on a Monday. %s');
    }

    function testEndsAfter_DiscreteMonths()
    {
        $now = new Date('2001-02-15');
        $jan = new DateRange($now);
        $feb = new DateRange($now);
        $jan->useLastMonth();
        $feb->useThisMonth();

        $this->assertTrue($feb->endsAfter($jan), 'February ends after January.');
    }

    function testEndsAfter_DiscreteMonths_NotAfter()
    {
        $now = new Date('2001-02-15');
        $jan = new DateRange($now);
        $feb = new DateRange($now);
        $jan->useLastMonth();
        $feb->useThisMonth();

        $this->assertFalse($jan->endsAfter($feb), 'January doesn\'t end after February.');
    }

    function testStartsBefore_DiscreteMonths()
    {
        $now = new Date('2001-02-15');
        $month = new DateRange($now);
        $week = new DateRange($now);

        $month->useThisMonth();
        $week->useThisWeek();

        $this->assertTrue($month->startsBefore($week), 'The month starts on the 1st, well before the week starts.');
    }

    function testStartsBefore_NotBefore()
    {
        $now = new Date('2001-02-15');
        $month = new DateRange($now);
        $week = new DateRange($now);

        $month->useThisMonth();
        $week->useThisWeek();

        $this->assertFalse($week->startsBefore($month), 'The month starts on the 1st, the week does not start before then.');
    }
}

?>
