<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: adjs.plugin.php 4612 2006-04-05 17:02:39Z chris@m3.net $
*/

/**
 * @package    MaxPlugins
 * @subpackage InvocationTags
 * @author     Radek Maciaszek <radek@m3.net>
 *
 */

require_once MAX_PATH . '/plugins/invocationTags/InvocationTags.php';
require_once MAX_PATH . '/lib/max/Plugin/Translation.php';

/**
 *
 * Invocation tag plugin.
 *
 */
class Plugins_InvocationTags_adjs_adjs extends Plugins_InvocationTags
{

    /**
     * Return name of plugin
     *
     * @return string
     */
    function getName()
    {
        return MAX_Plugin_Translation::translate('Javascript Tag', $this->module, $this->package);
    }

    /**
     * Return preference code
     *
     * @return string
     */
    function getPreferenceCode()
    {
        return 'allow_invocation_js';
    }

    /**
     * Check if plugin is allowed
     *
     * @return boolean  True - allowed, false - not allowed
     */
    function isAllowed($extra)
    {
        $isAllowed = parent::isAllowed($extra);
        return $isAllowed;
    }

    /**
     * Return list of options
     *
     * @return array    Group of options
     */
    function getOptionsList()
    {
        $options = array (
            'spacer'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'what'          => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            //'clientid'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'campaignid'    => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'block'         => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'target'        => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'source'        => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'withtext'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'blockcampaign' => MAX_PLUGINS_INVOCATION_TAGS_STANDARD
        );

        return $options;
    }

    /**
     * Return invocation code for this plugin (codetype)
     *
     * @return string
     */
    function generateInvocationCode()
    {
        parent::prepareCommonInvocationData();

        $conf = $GLOBALS['_MAX']['CONF'];
        $mi = &$this->maxInvocation;

        $buffer  = '<!-- Max Media Manager ' . MAX_Plugin_Translation::translate('Javascript Tag', $this->module, $this->package) . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- Generated with Max ' . MAX_VERSION_READABLE . "\n";
        $buffer .= '  --';
        // Support for 3rd party server clicktracking
        if (isset($mi->thirdpartytrack) && $mi->thirdpartytrack == '1') {
            $buffer .= MAX_Plugin_Translation::translate('Third Party Comment', $this->module, $this->package);
        }
        $buffer .= MAX_Plugin_Translation::translate('Comment', $this->module, $this->package) . "\n\n";
        if (isset($mi->withtext) && $mi->withtext != '0') {
            $mi->parameters['withtext'] = "withtext=1";
        }
        if (isset($mi->block) && $mi->block == '1') {
            $mi->parameters['block'] = "block=1";
        }
        if (isset($mi->blockcampaign) && $mi->blockcampaign == '1') {
            $mi->parameters['blockcampaign'] = "blockcampaign=1";
        }
        if (isset($mi->campaignid) && ($mi->campaignid != '')) {
            $mi->parameters['campaignid'] = "campaignid=".$mi->campaignid;
        }
        $buffer .= "<script language='JavaScript' type='text/javascript'>\n";
        $buffer .= "<!--\n";
        // Support for 3rd party server clicktracking
        if (isset($mi->thirdpartytrack) && $mi->thirdpartytrack == '1') {
            $buffer .= "   // " . MAX_Plugin_Translation::translate('Insert click tracking URL here', $this->module, $this->package) . "\n";
            $buffer .= "   document.phpAds_ct0 ='Insert_Clicktrack_URL_Here'\n\n";
        }
        $buffer .= "   var m3_p = location.protocol=='https:'?'https:':'http:';\n";
        $buffer .= "   var m3_u = location.protocol=='https:'?'".constructPartialDeliveryUrl($conf['file']['js'], true)."':'".constructPartialDeliveryUrl($conf['file']['js'])."';\n";
        $buffer .= "   var m3_r = Math.floor(Math.random()*99999999999);\n";
        $buffer .= "   if (!document.phpAds_used) document.phpAds_used = ',';\n";
        $buffer .= "   document.write (\"<\" + \"script language='JavaScript'\" );\n";
        $buffer .= "   document.write (\"type='text/javascript' src='\");\n";
        $buffer .= "   document.write (m3_p + m3_u + \"?n=".$mi->uniqueid."\");\n";
        if (sizeof($mi->parameters) > 0) {
            $buffer .= "   document.write (\"&".implode ("&", $mi->parameters)."\");\n";
        }
        $buffer .= "   document.write (\"&exclude=\" + document.phpAds_used);\n";
        $buffer .= "   document.write (\"&loc=\" + escape(window.location));\n";
        $buffer .= "   if (document.referrer)\n";
        $buffer .= "      document.write (\"&referer=\" + escape(document.referrer));\n";
        $buffer .= "   document.write ('&r=' + m3_r);\n";
        $buffer .= "   document.write (\"&ct0=\" + escape(document.phpAds_ct0));\n";
        $buffer .= "   if (document.mmm_fo) document.write (\"&mmm_fo=1\");\n";
        $buffer .= "   document.write (\"'><\" + \"/script>\");\n";
        $buffer .= "//-->\n";
        $buffer .= "</script>\n";
        if (isset($mi->parameters['withtext'])) {
            unset ($mi->parameters['withtext']);
        }
        if (isset($mi->parameters['block'])) {
            unset ($mi->parameters['block']);
        }
        if (isset($mi->parameters['blockcampaign'])) {
            unset ($mi->parameters['blockcampaign']);
        }
        if (isset($mi->parameters['target'])) {
            unset ($mi->parameters['target']);
        }
        if (!empty($mi->uniqueid)) {
            $mi->parameters['n'] = "n=".$mi->uniqueid;
        }
        if ($mi->extra['delivery'] != phpAds_ZoneText) {
            $buffer .= "<noscript><a href='".constructDeliveryURL($conf['file']['click']);
            $buffer .= "?n=".$mi->uniqueid;
            $buffer .= "'";
            if (!empty($mi->target)) {
                $buffer .= " target='".$mi->target."'";
            } else {
                $buffer .= " target='_blank'";
            }
            $buffer .= "><img src='".constructDeliveryURL($conf['file']['view']);
            if (sizeof($mi->parameters) > 0) {
                $buffer .= "?".implode ("&", $mi->parameters);
            }
            $buffer .= "' border='0' alt='' /></a></noscript>\n";
        }

        return $buffer;
    }

}

?>